Class: Aws::PinpointEmail::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PinpointEmail::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-pinpointemail/client.rb,
sig/client.rbs
Overview
An API client for PinpointEmail. To construct a client, you need to configure a :region and :credentials.
client = Aws::PinpointEmail::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateConfigurationSetEventDestinationResponseSuccess, _CreateConfigurationSetResponseSuccess, _CreateDedicatedIpPoolResponseSuccess, _CreateDeliverabilityTestReportResponseSuccess, _CreateEmailIdentityResponseSuccess, _DeleteConfigurationSetEventDestinationResponseSuccess, _DeleteConfigurationSetResponseSuccess, _DeleteDedicatedIpPoolResponseSuccess, _DeleteEmailIdentityResponseSuccess, _GetAccountResponseSuccess, _GetBlacklistReportsResponseSuccess, _GetConfigurationSetEventDestinationsResponseSuccess, _GetConfigurationSetResponseSuccess, _GetDedicatedIpResponseSuccess, _GetDedicatedIpsResponseSuccess, _GetDeliverabilityDashboardOptionsResponseSuccess, _GetDeliverabilityTestReportResponseSuccess, _GetDomainDeliverabilityCampaignResponseSuccess, _GetDomainStatisticsReportResponseSuccess, _GetEmailIdentityResponseSuccess, _ListConfigurationSetsResponseSuccess, _ListDedicatedIpPoolsResponseSuccess, _ListDeliverabilityTestReportsResponseSuccess, _ListDomainDeliverabilityCampaignsResponseSuccess, _ListEmailIdentitiesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutAccountDedicatedIpWarmupAttributesResponseSuccess, _PutAccountSendingAttributesResponseSuccess, _PutConfigurationSetDeliveryOptionsResponseSuccess, _PutConfigurationSetReputationOptionsResponseSuccess, _PutConfigurationSetSendingOptionsResponseSuccess, _PutConfigurationSetTrackingOptionsResponseSuccess, _PutDedicatedIpInPoolResponseSuccess, _PutDedicatedIpWarmupAttributesResponseSuccess, _PutDeliverabilityDashboardOptionResponseSuccess, _PutEmailIdentityDkimAttributesResponseSuccess, _PutEmailIdentityFeedbackAttributesResponseSuccess, _PutEmailIdentityMailFromAttributesResponseSuccess, _SendEmailResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateConfigurationSetEventDestinationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_configuration_set(params = {}) ⇒ Struct
Create a configuration set.
-
#create_configuration_set_event_destination(params = {}) ⇒ Struct
Create an event destination.
-
#create_dedicated_ip_pool(params = {}) ⇒ Struct
Create a new pool of dedicated IP addresses.
-
#create_deliverability_test_report(params = {}) ⇒ Types::CreateDeliverabilityTestReportResponse
Create a new predictive inbox placement test.
-
#create_email_identity(params = {}) ⇒ Types::CreateEmailIdentityResponse
Verifies an email identity for use with Amazon Pinpoint.
-
#delete_configuration_set(params = {}) ⇒ Struct
Delete an existing configuration set.
-
#delete_configuration_set_event_destination(params = {}) ⇒ Struct
Delete an event destination.
-
#delete_dedicated_ip_pool(params = {}) ⇒ Struct
Delete a dedicated IP pool.
-
#delete_email_identity(params = {}) ⇒ Struct
Deletes an email identity that you previously verified for use with Amazon Pinpoint.
-
#get_account(params = {}) ⇒ Types::GetAccountResponse
Obtain information about the email-sending status and capabilities of your Amazon Pinpoint account in the current AWS Region.
-
#get_blacklist_reports(params = {}) ⇒ Types::GetBlacklistReportsResponse
Retrieve a list of the blacklists that your dedicated IP addresses appear on.
-
#get_configuration_set(params = {}) ⇒ Types::GetConfigurationSetResponse
Get information about an existing configuration set, including the dedicated IP pool that it's associated with, whether or not it's enabled for sending email, and more.
-
#get_configuration_set_event_destinations(params = {}) ⇒ Types::GetConfigurationSetEventDestinationsResponse
Retrieve a list of event destinations that are associated with a configuration set.
-
#get_dedicated_ip(params = {}) ⇒ Types::GetDedicatedIpResponse
Get information about a dedicated IP address, including the name of the dedicated IP pool that it's associated with, as well information about the automatic warm-up process for the address.
-
#get_dedicated_ips(params = {}) ⇒ Types::GetDedicatedIpsResponse
List the dedicated IP addresses that are associated with your Amazon Pinpoint account.
-
#get_deliverability_dashboard_options(params = {}) ⇒ Types::GetDeliverabilityDashboardOptionsResponse
Retrieve information about the status of the Deliverability dashboard for your Amazon Pinpoint account.
-
#get_deliverability_test_report(params = {}) ⇒ Types::GetDeliverabilityTestReportResponse
Retrieve the results of a predictive inbox placement test.
-
#get_domain_deliverability_campaign(params = {}) ⇒ Types::GetDomainDeliverabilityCampaignResponse
Retrieve all the deliverability data for a specific campaign.
-
#get_domain_statistics_report(params = {}) ⇒ Types::GetDomainStatisticsReportResponse
Retrieve inbox placement and engagement rates for the domains that you use to send email.
-
#get_email_identity(params = {}) ⇒ Types::GetEmailIdentityResponse
Provides information about a specific identity associated with your Amazon Pinpoint account, including the identity's verification status, its DKIM authentication status, and its custom Mail-From settings.
-
#list_configuration_sets(params = {}) ⇒ Types::ListConfigurationSetsResponse
List all of the configuration sets associated with your Amazon Pinpoint account in the current region.
-
#list_dedicated_ip_pools(params = {}) ⇒ Types::ListDedicatedIpPoolsResponse
List all of the dedicated IP pools that exist in your Amazon Pinpoint account in the current AWS Region.
-
#list_deliverability_test_reports(params = {}) ⇒ Types::ListDeliverabilityTestReportsResponse
Show a list of the predictive inbox placement tests that you've performed, regardless of their statuses.
-
#list_domain_deliverability_campaigns(params = {}) ⇒ Types::ListDomainDeliverabilityCampaignsResponse
Retrieve deliverability data for all the campaigns that used a specific domain to send email during a specified time range.
-
#list_email_identities(params = {}) ⇒ Types::ListEmailIdentitiesResponse
Returns a list of all of the email identities that are associated with your Amazon Pinpoint account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieve a list of the tags (keys and values) that are associated with a specified resource.
-
#put_account_dedicated_ip_warmup_attributes(params = {}) ⇒ Struct
Enable or disable the automatic warm-up feature for dedicated IP addresses.
-
#put_account_sending_attributes(params = {}) ⇒ Struct
Enable or disable the ability of your account to send email.
-
#put_configuration_set_delivery_options(params = {}) ⇒ Struct
Associate a configuration set with a dedicated IP pool.
-
#put_configuration_set_reputation_options(params = {}) ⇒ Struct
Enable or disable collection of reputation metrics for emails that you send using a particular configuration set in a specific AWS Region.
-
#put_configuration_set_sending_options(params = {}) ⇒ Struct
Enable or disable email sending for messages that use a particular configuration set in a specific AWS Region.
-
#put_configuration_set_tracking_options(params = {}) ⇒ Struct
Specify a custom domain to use for open and click tracking elements in email that you send using Amazon Pinpoint.
-
#put_dedicated_ip_in_pool(params = {}) ⇒ Struct
Move a dedicated IP address to an existing dedicated IP pool.
-
#put_dedicated_ip_warmup_attributes(params = {}) ⇒ Struct
Returns an empty response.
-
#put_deliverability_dashboard_option(params = {}) ⇒ Struct
Enable or disable the Deliverability dashboard for your Amazon Pinpoint account.
-
#put_email_identity_dkim_attributes(params = {}) ⇒ Struct
Used to enable or disable DKIM authentication for an email identity.
-
#put_email_identity_feedback_attributes(params = {}) ⇒ Struct
Used to enable or disable feedback forwarding for an identity.
-
#put_email_identity_mail_from_attributes(params = {}) ⇒ Struct
Used to enable or disable the custom Mail-From domain configuration for an email identity.
-
#send_email(params = {}) ⇒ Types::SendEmailResponse
Sends an email message.
-
#tag_resource(params = {}) ⇒ Struct
Add one or more tags (keys and values) to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Remove one or more tags (keys and values) from a specified resource.
-
#update_configuration_set_event_destination(params = {}) ⇒ Struct
Update the configuration of an event destination for a configuration set.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-pinpointemail/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2423 2424 2425 |
# File 'lib/aws-sdk-pinpointemail/client.rb', line 2423 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2426 2427 2428 |
# File 'lib/aws-sdk-pinpointemail/client.rb', line 2426 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 |
# File 'lib/aws-sdk-pinpointemail/client.rb', line 2396 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PinpointEmail') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-pinpointemail' context[:gem_version] = '1.84.0' Seahorse::Client::Request.new(handlers, context) end |
#create_configuration_set(params = {}) ⇒ Struct
Create a configuration set. Configuration sets are groups of rules that you can apply to the emails you send using Amazon Pinpoint. You apply a configuration set to an email by including a reference to the configuration set in the headers of the email. When you apply a configuration set to an email, all of the rules in that configuration set are applied to the email.
85 |
# File 'sig/client.rbs', line 85
def create_configuration_set: (
|
#create_configuration_set_event_destination(params = {}) ⇒ Struct
Create an event destination. In Amazon Pinpoint, events include message sends, deliveries, opens, clicks, bounces, and complaints. Event destinations are places that you can send information about these events to. For example, you can send event data to Amazon SNS to receive notifications when you receive bounces or complaints, or you can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for long-term storage.
A single configuration set can include more than one event destination.
114 |
# File 'sig/client.rbs', line 114
def create_configuration_set_event_destination: (
|
#create_dedicated_ip_pool(params = {}) ⇒ Struct
Create a new pool of dedicated IP addresses. A pool can include one or more dedicated IP addresses that are associated with your Amazon Pinpoint account. You can associate a pool with a configuration set. When you send an email that uses that configuration set, Amazon Pinpoint sends it using only the IP addresses in the associated pool.
125 |
# File 'sig/client.rbs', line 125
def create_dedicated_ip_pool: (
|
#create_deliverability_test_report(params = {}) ⇒ Types::CreateDeliverabilityTestReportResponse
Create a new predictive inbox placement test. Predictive inbox
placement tests can help you predict how your messages will be handled
by various email providers around the world. When you perform a
predictive inbox placement test, you provide a sample message that
contains the content that you plan to send to your customers. Amazon
Pinpoint then sends that message to special email addresses spread
across several major email providers. After about 24 hours, the test
is complete, and you can use the GetDeliverabilityTestReport
operation to view the results of the test.
142 |
# File 'sig/client.rbs', line 142
def create_deliverability_test_report: (
|
#create_email_identity(params = {}) ⇒ Types::CreateEmailIdentityResponse
Verifies an email identity for use with Amazon Pinpoint. In Amazon Pinpoint, an identity is an email address or domain that you use when you send email. Before you can use an identity to send email with Amazon Pinpoint, you first have to verify it. By verifying an address, you demonstrate that you're the owner of the address, and that you've given Amazon Pinpoint permission to send email from the address.
When you verify an email address, Amazon Pinpoint sends an email to the address. Your email address is verified as soon as you follow the link in the verification email.
When you verify a domain, this operation provides a set of DKIM tokens, which you can convert into CNAME tokens. You add these CNAME tokens to the DNS configuration for your domain. Your domain is verified when Amazon Pinpoint detects these records in the DNS configuration for your domain. It usually takes around 72 hours to complete the domain verification process.
162 |
# File 'sig/client.rbs', line 162
def create_email_identity: (
|
#delete_configuration_set(params = {}) ⇒ Struct
Delete an existing configuration set.
In Amazon Pinpoint, configuration sets are groups of rules that you can apply to the emails you send. You apply a configuration set to an email by including a reference to the configuration set in the headers of the email. When you apply a configuration set to an email, all of the rules in that configuration set are applied to the email.
177 |
# File 'sig/client.rbs', line 177
def delete_configuration_set: (
|
#delete_configuration_set_event_destination(params = {}) ⇒ Struct
Delete an event destination.
In Amazon Pinpoint, events include message sends, deliveries, opens, clicks, bounces, and complaints. Event destinations are places that you can send information about these events to. For example, you can send event data to Amazon SNS to receive notifications when you receive bounces or complaints, or you can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for long-term storage.
186 |
# File 'sig/client.rbs', line 186
def delete_configuration_set_event_destination: (
|
#delete_dedicated_ip_pool(params = {}) ⇒ Struct
Delete a dedicated IP pool.
196 |
# File 'sig/client.rbs', line 196
def delete_dedicated_ip_pool: (
|
#delete_email_identity(params = {}) ⇒ Struct
Deletes an email identity that you previously verified for use with Amazon Pinpoint. An identity can be either an email address or a domain name.
205 |
# File 'sig/client.rbs', line 205
def delete_email_identity: (
|
#get_account(params = {}) ⇒ Types::GetAccountResponse
Obtain information about the email-sending status and capabilities of your Amazon Pinpoint account in the current AWS Region.
219 |
# File 'sig/client.rbs', line 219
def get_account: (
|
#get_blacklist_reports(params = {}) ⇒ Types::GetBlacklistReportsResponse
Retrieve a list of the blacklists that your dedicated IP addresses appear on.
228 |
# File 'sig/client.rbs', line 228
def get_blacklist_reports: (
|
#get_configuration_set(params = {}) ⇒ Types::GetConfigurationSetResponse
Get information about an existing configuration set, including the dedicated IP pool that it's associated with, whether or not it's enabled for sending email, and more.
In Amazon Pinpoint, configuration sets are groups of rules that you can apply to the emails you send. You apply a configuration set to an email by including a reference to the configuration set in the headers of the email. When you apply a configuration set to an email, all of the rules in that configuration set are applied to the email.
243 |
# File 'sig/client.rbs', line 243
def get_configuration_set: (
|
#get_configuration_set_event_destinations(params = {}) ⇒ Types::GetConfigurationSetEventDestinationsResponse
Retrieve a list of event destinations that are associated with a configuration set.
In Amazon Pinpoint, events include message sends, deliveries, opens, clicks, bounces, and complaints. Event destinations are places that you can send information about these events to. For example, you can send event data to Amazon SNS to receive notifications when you receive bounces or complaints, or you can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for long-term storage.
253 |
# File 'sig/client.rbs', line 253
def get_configuration_set_event_destinations: (
|
#get_dedicated_ip(params = {}) ⇒ Types::GetDedicatedIpResponse
Get information about a dedicated IP address, including the name of the dedicated IP pool that it's associated with, as well information about the automatic warm-up process for the address.
263 |
# File 'sig/client.rbs', line 263
def get_dedicated_ip: (
|
#get_dedicated_ips(params = {}) ⇒ Types::GetDedicatedIpsResponse
List the dedicated IP addresses that are associated with your Amazon Pinpoint account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
274 |
# File 'sig/client.rbs', line 274
def get_dedicated_ips: (
|
#get_deliverability_dashboard_options(params = {}) ⇒ Types::GetDeliverabilityDashboardOptionsResponse
Retrieve information about the status of the Deliverability dashboard for your Amazon Pinpoint account. When the Deliverability dashboard is enabled, you gain access to reputation, deliverability, and other metrics for the domains that you use to send email using Amazon Pinpoint. You also gain the ability to perform predictive inbox placement tests.
When you use the Deliverability dashboard, you pay a monthly subscription charge, in addition to any other fees that you accrue by using Amazon Pinpoint. For more information about the features and cost of a Deliverability dashboard subscription, see Amazon Pinpoint Pricing.
290 |
# File 'sig/client.rbs', line 290
def get_deliverability_dashboard_options: (
|
#get_deliverability_test_report(params = {}) ⇒ Types::GetDeliverabilityTestReportResponse
Retrieve the results of a predictive inbox placement test.
303 |
# File 'sig/client.rbs', line 303
def get_deliverability_test_report: (
|
#get_domain_deliverability_campaign(params = {}) ⇒ Types::GetDomainDeliverabilityCampaignResponse
Retrieve all the deliverability data for a specific campaign. This
data is available for a campaign only if the campaign sent email by
using a domain that the Deliverability dashboard is enabled for
(PutDeliverabilityDashboardOption operation).
313 |
# File 'sig/client.rbs', line 313
def get_domain_deliverability_campaign: (
|
#get_domain_statistics_report(params = {}) ⇒ Types::GetDomainStatisticsReportResponse
Retrieve inbox placement and engagement rates for the domains that you use to send email.
324 |
# File 'sig/client.rbs', line 324
def get_domain_statistics_report: (
|
#get_email_identity(params = {}) ⇒ Types::GetEmailIdentityResponse
Provides information about a specific identity associated with your Amazon Pinpoint account, including the identity's verification status, its DKIM authentication status, and its custom Mail-From settings.
341 |
# File 'sig/client.rbs', line 341
def get_email_identity: (
|
#list_configuration_sets(params = {}) ⇒ Types::ListConfigurationSetsResponse
List all of the configuration sets associated with your Amazon Pinpoint account in the current region.
In Amazon Pinpoint, configuration sets are groups of rules that you can apply to the emails you send. You apply a configuration set to an email by including a reference to the configuration set in the headers of the email. When you apply a configuration set to an email, all of the rules in that configuration set are applied to the email.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
352 |
# File 'sig/client.rbs', line 352
def list_configuration_sets: (
|
#list_dedicated_ip_pools(params = {}) ⇒ Types::ListDedicatedIpPoolsResponse
List all of the dedicated IP pools that exist in your Amazon Pinpoint account in the current AWS Region.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
364 |
# File 'sig/client.rbs', line 364
def list_dedicated_ip_pools: (
|
#list_deliverability_test_reports(params = {}) ⇒ Types::ListDeliverabilityTestReportsResponse
Show a list of the predictive inbox placement tests that you've
performed, regardless of their statuses. For predictive inbox
placement tests that are complete, you can use the
GetDeliverabilityTestReport operation to view the results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
376 |
# File 'sig/client.rbs', line 376
def list_deliverability_test_reports: (
|
#list_domain_deliverability_campaigns(params = {}) ⇒ Types::ListDomainDeliverabilityCampaignsResponse
Retrieve deliverability data for all the campaigns that used a
specific domain to send email during a specified time range. This data
is available for a domain only if you enabled the Deliverability
dashboard (PutDeliverabilityDashboardOption operation) for the
domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
388 |
# File 'sig/client.rbs', line 388
def list_domain_deliverability_campaigns: (
|
#list_email_identities(params = {}) ⇒ Types::ListEmailIdentitiesResponse
Returns a list of all of the email identities that are associated with your Amazon Pinpoint account. An identity can be either an email address or a domain. This operation returns identities that are verified as well as those that aren't.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
403 |
# File 'sig/client.rbs', line 403
def list_email_identities: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieve a list of the tags (keys and values) that are associated with a specified resource. A tag is a label that you optionally define and associate with a resource in Amazon Pinpoint. Each tag consists of a required tag key and an optional associated tag value. A tag key is a general label that acts as a category for more specific tag values. A tag value acts as a descriptor within a tag key.
414 |
# File 'sig/client.rbs', line 414
def list_tags_for_resource: (
|
#put_account_dedicated_ip_warmup_attributes(params = {}) ⇒ Struct
Enable or disable the automatic warm-up feature for dedicated IP addresses.
423 |
# File 'sig/client.rbs', line 423
def put_account_dedicated_ip_warmup_attributes: (
|
#put_account_sending_attributes(params = {}) ⇒ Struct
Enable or disable the ability of your account to send email.
432 |
# File 'sig/client.rbs', line 432
def put_account_sending_attributes: (
|
#put_configuration_set_delivery_options(params = {}) ⇒ Struct
Associate a configuration set with a dedicated IP pool. You can use dedicated IP pools to create groups of dedicated IP addresses for sending specific types of email.
441 |
# File 'sig/client.rbs', line 441
def put_configuration_set_delivery_options: (
|
#put_configuration_set_reputation_options(params = {}) ⇒ Struct
Enable or disable collection of reputation metrics for emails that you send using a particular configuration set in a specific AWS Region.
452 |
# File 'sig/client.rbs', line 452
def put_configuration_set_reputation_options: (
|
#put_configuration_set_sending_options(params = {}) ⇒ Struct
Enable or disable email sending for messages that use a particular configuration set in a specific AWS Region.
462 |
# File 'sig/client.rbs', line 462
def put_configuration_set_sending_options: (
|
#put_configuration_set_tracking_options(params = {}) ⇒ Struct
Specify a custom domain to use for open and click tracking elements in email that you send using Amazon Pinpoint.
472 |
# File 'sig/client.rbs', line 472
def put_configuration_set_tracking_options: (
|
#put_dedicated_ip_in_pool(params = {}) ⇒ Struct
Move a dedicated IP address to an existing dedicated IP pool.
The dedicated IP pool you specify must already exist. You can create a
new pool by using the CreateDedicatedIpPool operation.
482 |
# File 'sig/client.rbs', line 482
def put_dedicated_ip_in_pool: (
|
#put_dedicated_ip_warmup_attributes(params = {}) ⇒ Struct
Returns an empty response.
492 |
# File 'sig/client.rbs', line 492
def put_dedicated_ip_warmup_attributes: (
|
#put_deliverability_dashboard_option(params = {}) ⇒ Struct
Enable or disable the Deliverability dashboard for your Amazon Pinpoint account. When you enable the Deliverability dashboard, you gain access to reputation, deliverability, and other metrics for the domains that you use to send email using Amazon Pinpoint. You also gain the ability to perform predictive inbox placement tests.
When you use the Deliverability dashboard, you pay a monthly subscription charge, in addition to any other fees that you accrue by using Amazon Pinpoint. For more information about the features and cost of a Deliverability dashboard subscription, see Amazon Pinpoint Pricing.
502 |
# File 'sig/client.rbs', line 502
def put_deliverability_dashboard_option: (
|
#put_email_identity_dkim_attributes(params = {}) ⇒ Struct
Used to enable or disable DKIM authentication for an email identity.
521 |
# File 'sig/client.rbs', line 521
def put_email_identity_dkim_attributes: (
|
#put_email_identity_feedback_attributes(params = {}) ⇒ Struct
Used to enable or disable feedback forwarding for an identity. This setting determines what happens when an identity is used to send an email that results in a bounce or complaint event.
When you enable feedback forwarding, Amazon Pinpoint sends you email notifications when bounce or complaint events occur. Amazon Pinpoint sends this notification to the address that you specified in the Return-Path header of the original email.
When you disable feedback forwarding, Amazon Pinpoint sends notifications through other mechanisms, such as by notifying an Amazon SNS topic. You're required to have a method of tracking bounces and complaints. If you haven't set up another mechanism for receiving bounce or complaint notifications, Amazon Pinpoint sends an email notification when these events occur (even if this setting is disabled).
531 |
# File 'sig/client.rbs', line 531
def put_email_identity_feedback_attributes: (
|
#put_email_identity_mail_from_attributes(params = {}) ⇒ Struct
Used to enable or disable the custom Mail-From domain configuration for an email identity.
541 |
# File 'sig/client.rbs', line 541
def put_email_identity_mail_from_attributes: (
|
#send_email(params = {}) ⇒ Types::SendEmailResponse
Sends an email message. You can use the Amazon Pinpoint Email API to send two types of messages:
-
Simple – A standard email message. When you create this type of message, you specify the sender, the recipient, and the message body, and Amazon Pinpoint assembles the message for you.
-
Raw – A raw, MIME-formatted email message. When you send this type of email, you have to specify all of the message headers, as well as the message body. You can use this message type to send messages that contain attachments. The message that you specify has to be a valid MIME message.
553 |
# File 'sig/client.rbs', line 553
def send_email: (
|
#tag_resource(params = {}) ⇒ Struct
Add one or more tags (keys and values) to a specified resource. A tag is a label that you optionally define and associate with a resource in Amazon Pinpoint. Tags can help you categorize and manage resources in different ways, such as by purpose, owner, environment, or other criteria. A resource can have as many as 50 tags.
Each tag consists of a required tag key and an associated tag value, both of which you define. A tag key is a general label that acts as a category for more specific tag values. A tag value acts as a descriptor within a tag key.
577 |
# File 'sig/client.rbs', line 577
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Remove one or more tags (keys and values) from a specified resource.
592 |
# File 'sig/client.rbs', line 592
def untag_resource: (
|
#update_configuration_set_event_destination(params = {}) ⇒ Struct
Update the configuration of an event destination for a configuration set.
In Amazon Pinpoint, events include message sends, deliveries, opens, clicks, bounces, and complaints. Event destinations are places that you can send information about these events to. For example, you can send event data to Amazon SNS to receive notifications when you receive bounces or complaints, or you can use Amazon Kinesis Data Firehose to stream data to Amazon S3 for long-term storage.
602 |
# File 'sig/client.rbs', line 602
def update_configuration_set_event_destination: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2416 2417 2418 |
# File 'lib/aws-sdk-pinpointemail/client.rb', line 2416 def waiter_names [] end |