Class: Aws::PinpointEmail::Types::GetDomainStatisticsReportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointEmail::Types::GetDomainStatisticsReportResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointemail/types.rb
Overview
An object that includes statistics that are related to the domain that you specified.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#daily_volumes ⇒ Array<Types::DailyVolume>
An object that contains deliverability metrics for the domain that you specified.
-
#overall_volume ⇒ Types::OverallVolume
An object that contains deliverability metrics for the domain that you specified.
Instance Attribute Details
#daily_volumes ⇒ Array<Types::DailyVolume>
An object that contains deliverability metrics for the domain that you specified. This object contains data for each day, starting on the StartDate and ending on the EndDate.
1578 1579 1580 1581 1582 1583 |
# File 'lib/aws-sdk-pinpointemail/types.rb', line 1578 class GetDomainStatisticsReportResponse < Struct.new( :overall_volume, :daily_volumes) SENSITIVE = [] include Aws::Structure end |
#overall_volume ⇒ Types::OverallVolume
An object that contains deliverability metrics for the domain that you specified. The data in this object is a summary of all of the data that was collected from the StartDate to the EndDate.
1578 1579 1580 1581 1582 1583 |
# File 'lib/aws-sdk-pinpointemail/types.rb', line 1578 class GetDomainStatisticsReportResponse < Struct.new( :overall_volume, :daily_volumes) SENSITIVE = [] include Aws::Structure end |