Class: Aws::PinpointEmail::Types::ListConfigurationSetsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointEmail::Types::ListConfigurationSetsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointemail/types.rb
Overview
A list of configuration sets in your Amazon Pinpoint account in the current AWS Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_sets ⇒ Array<String>
An array that contains all of the configuration sets in your Amazon Pinpoint account in the current AWS Region.
-
#next_token ⇒ String
A token that indicates that there are additional configuration sets to list.
Instance Attribute Details
#configuration_sets ⇒ Array<String>
An array that contains all of the configuration sets in your Amazon Pinpoint account in the current AWS Region.
1818 1819 1820 1821 1822 1823 |
# File 'lib/aws-sdk-pinpointemail/types.rb', line 1818 class ListConfigurationSetsResponse < Struct.new( :configuration_sets, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates that there are additional configuration sets
to list. To view additional configuration sets, issue another
request to ListConfigurationSets, and pass this token in the
NextToken parameter.
1818 1819 1820 1821 1822 1823 |
# File 'lib/aws-sdk-pinpointemail/types.rb', line 1818 class ListConfigurationSetsResponse < Struct.new( :configuration_sets, :next_token) SENSITIVE = [] include Aws::Structure end |