Class: Aws::PinpointEmail::Types::ListDedicatedIpPoolsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::PinpointEmail::Types::ListDedicatedIpPoolsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-pinpointemail/types.rb
Overview
A request to obtain a list of dedicated IP pools.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token returned from a previous call to
ListDedicatedIpPoolsto indicate the position in the list of dedicated IP pools. -
#page_size ⇒ Integer
The number of results to show in a single call to
ListDedicatedIpPools.
Instance Attribute Details
#next_token ⇒ String
A token returned from a previous call to ListDedicatedIpPools to
indicate the position in the list of dedicated IP pools.
1841 1842 1843 1844 1845 1846 |
# File 'lib/aws-sdk-pinpointemail/types.rb', line 1841 class ListDedicatedIpPoolsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of results to show in a single call to
ListDedicatedIpPools. If the number of results is larger than the
number you specified in this parameter, then the response includes a
NextToken element, which you can use to obtain additional results.
1841 1842 1843 1844 1845 1846 |
# File 'lib/aws-sdk-pinpointemail/types.rb', line 1841 class ListDedicatedIpPoolsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |